@@ -129,7 +129,8 @@ class TestEnvironment(object):
             data = f.read()
             local_config = json.loads(data % self.options)
 
-        return serve.merge_json(default_config, local_config)
+        rv = serve.merge_json(default_config, local_config)
+        return rv
 
     def copy_required_files(self):
         logger.info("Placing required files in server environment.")
@@ -149,7 +150,7 @@ class TestEnvironment(object):
         time.sleep(2)
         for scheme, servers in self.servers.iteritems():
             for port, server in servers:
-                if not self.test_server_port:
+                if self.test_server_port:
                     s = socket.socket()
                     try:
                         s.connect((self.config["host"], port))
